summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/schema.py
diff options
context:
space:
mode:
authorMike Bayer <mike_mp@zzzcomputing.com>2010-12-13 00:15:32 -0500
committerMike Bayer <mike_mp@zzzcomputing.com>2010-12-13 00:15:32 -0500
commit86e8e7c558b296018613ed979012b2aca493ffbb (patch)
tree62340b7d477c59d9ba7c2c2cad488652176188d8 /lib/sqlalchemy/schema.py
parent1125a4b8b1a7b41111396b5b58887047a847b59e (diff)
downloadsqlalchemy-86e8e7c558b296018613ed979012b2aca493ffbb.tar.gz
- why type.dialect_impl(dialect).bind_processor(dialect), caching just the impl?
just call type._cached_bind_processor(dialect), cache the impl *and* the processor function. same for result sets. - use plain dict + update for defaultexecutioncontext.execution_options
Diffstat (limited to 'lib/sqlalchemy/schema.py')
-rw-r--r--lib/sqlalchemy/schema.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/sqlalchemy/schema.py b/lib/sqlalchemy/schema.py
index 6d6a4485d..cb6b27e36 100644
--- a/lib/sqlalchemy/schema.py
+++ b/lib/sqlalchemy/schema.py
@@ -504,7 +504,7 @@ class Column(SchemaItem, expression.ColumnClause):
usage within the :mod:`~sqlalchemy.ext.declarative` extension.
:param type\_: The column's type, indicated using an instance which
subclasses :class:`~sqlalchemy.types.AbstractType`. If no arguments
are required for the type, the class of the type can be sent
as well, e.g.::
@@ -684,9 +684,9 @@ class Column(SchemaItem, expression.ColumnClause):
if args:
coltype = args[0]
- if (isinstance(coltype, types.AbstractType) or
+ if (isinstance(coltype, types.TypeEngine) or
(isinstance(coltype, type) and
- issubclass(coltype, types.AbstractType))):
+ issubclass(coltype, types.TypeEngine))):
if type_ is not None:
raise exc.ArgumentError(
"May not pass type_ positionally and as a keyword.")
@@ -504,7 +504,7 @@ class Column(SchemaItem, expression.ColumnClause):
usage within the :mod:`~sqlalchemy.ext.declarative` extension.
:param type\_: The column's type, indicated using an instance which
- subclasses :class:`~sqlalchemy.types.AbstractType`. If no arguments
+ subclasses :class:`~sqlalchemy.types.TypeEngine`. If no arguments
are required for the type, the class of the type can be sent
as well, e.g.::